@@ -25,12 +25,8 @@
 #include <gtk/gtk.h>
 #include <math.h>
 #include <colord-gtk.h>
-#include <lcms2.h>
 #include <canberra-gtk.h>
 
-#define GNOME_DESKTOP_USE_UNSTABLE_API
-#include <libgnome-desktop/gnome-rr.h>
-
 #include "gcm-calibrate.h"
 #include "gcm-utils.h"
 #include "gcm-brightness.h"
